@@ -42,7 +42,7 @@ class Defaults(object):
 		# overwrite.
 		overwrite=False,
 	):
-		if sudo: sudo = "sudo "
+		if sudo or "--sudo" in sys.argv: sudo = "sudo "
 		else: sudo = ""
 		present = "--create-alias" in sys.argv and get_argument("--create-alias") == alias
 		base = f"/usr/local/bin"
